@@ -1,3 +1,4 @@
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 """Random Effects SEM."""
 import pandas as pd
@@ -229,7 +230,7 @@ class ModelEffects(ModelMeans):
         imp = ImputerEffects(self, data, group, k)
         res = imp.fit(solver='SLSQP')
         data = imp.get_fancy()
-        return data if not ret_opt else (data, res)
+        return data if not ret_opt else (data, res)        
 
     def effect_rf_covariance(self, items: dict):
         """
@@ -503,7 +504,7 @@ class ModelEffects(ModelMeans):
             q = self.mx_q
         else:
             s, q = np.linalg.eigh(self.mx_zkz)
-            self.mx_s = s
+            self.mx_s, self.mx_q = s, q
         self.mx_data_transformed = self.mx_data.T @ q
         self.mx_g = self.mx_g_orig @ q
         self.num_n = self.mx_data_transformed.shape[1]
