@@ -346,7 +346,7 @@ class ModelMeans(Model):
         if self.calc_fim is self.calc_fim_ml:
             self.prepare_fiml()
 
-    def fit(self, data=None, cov=None, obj='REML', solver='SLSQP', groups=None,
+    def fit(self, data=None, cov=None, obj='ML', solver='SLSQP', groups=None,
             clean_slate=False):
         """
         Fit model to data.
@@ -359,7 +359,7 @@ class ModelMeans(Model):
             Pre-computed covariance/correlation matrix. The default is None.
         obj : str, optional
             Objective function to minimize. Possible values are 'REML', "ML".
-            The default is 'FIML'.
+            The default is 'ML'.
         solver : TYPE, optional
             Optimizaiton method. Currently scipy-only methods are available.
             The default is 'SLSQP'.
@@ -685,6 +685,36 @@ class ModelMeans(Model):
                 grad[i] += tr + logdet_tr + mean_tr
         return np.array(grad)
 
+    '''
+    -------------------------Prediction method--------------------------------
+    '''
+
+    def predict_exo(self, exogenous: pd.DataFrame):
+        """
+        Predict output variables given a set of exogenous variables.
+
+        This method works much faster than "predict", however it can't be
+        utilised to impute missing data or to estimate factors as of now. It is
+        especially useful for phenotype prediction via a set of known SNPs.
+        Parameters
+        ----------
+        exogenous : pd.DataFrame
+            Observations of exogenous variables. Missing variables or mssing
+            data are converted to zeros.
+
+        Returns
+        -------
+        pd.DataFrame
+            DataFrame containing predictions of endogenous observed variables.
+
+        """
+        
+        g = exogenous[self.vars['observed_exogenous']].values.T 
+        t = np.linalg.inv(np.identity(self.mx_beta.shape[0]) - self.mx_beta)
+        t = (self.mx_lambda @ t @ self.mx_gamma1 + self.mx_gamma2) @ g
+        return pd.DataFrame(t.T, columns=self.vars['observed'],
+                            index=exogenous.index)
+
     '''
     -------------------------Fisher Information Matrix------------------------
     '''
@@ -813,3 +843,4 @@ class ModelMeans(Model):
                 fim_inv = np.linalg.pinv(fim)
             return (fim, fim_inv)
         return fim
+
